EventException class

Inheritance

Constructors

EventException(String message, {String? fix, String? cause})

Properties

cause → String?
finalinherited
fix → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited