ModuleException class

Exception thrown when module operations fail.

Inheritance

Constructors

ModuleException(String message, {String? moduleName, String? cause, String? fix})

Properties

cause → String?
finalinherited
fix → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
moduleName → String?
final
name → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited